@@ -1,6 +1,6 @@
 /*
  * pam_oath.c - a PAM module for OATH one-time passwords
- * Copyright (C) 2009-2021 Simon Josefsson
+ * Copyright (C) 2009-2023 Simon Josefsson
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -21,6 +21,7 @@
 #include <config.h>
 
 #include "oath.h"
+#include "pam_modutil.h"
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -43,9 +44,6 @@
 #ifdef HAVE_SECURITY_PAM_APPL_H
 #include <security/pam_appl.h>
 #endif
-#ifdef HAVE_SECURITY_PAM_MODUTIL_H
-#include <security/pam_modutil.h>
-#endif
 #ifdef HAVE_SECURITY_PAM_MODULES_H
 #include <security/pam_modules.h>
 #endif
@@ -149,6 +147,15 @@ parse_usersfile_str(pam_handle_t * pamh, const struct cfg *cfg, const char *user
     return PAM_BUF_ERR;
   }
 
+  if (strstr (cfg->usersfile, "${USER}") == NULL
+      && strstr (cfg->usersfile, "${HOME}") == NULL)
+    {
+      *usersfile = strdup (cfg->usersfile);
+      if (!*usersfile)
+	return PAM_BUF_ERR;
+      return PAM_SUCCESS;
+    }
+
   pw = pam_modutil_getpwnam(pamh, user);
   if(!pw)
     {
@@ -156,7 +163,7 @@ parse_usersfile_str(pam_handle_t * pamh, const struct cfg *cfg, const char *user
     }
 
   /*
-    Find occurances of the placeholder fields to determine
+    Find occurrences of the placeholder fields to determine
     userfile buffer length
   */
   name_len = strlen(pw->pw_name);
